==> pythonmommy-0.1.0.tar.gz: pythonmommy-0.1.0/README.md <==
# python-mommy

Mommy's here to support you when running python~ ❤️

THISBIS A PORT OF Gankra/cargo-mommy

# Installation

Install python-mommy like you would any other python package~

```text
> pip install python-mommy
```

# Usage

Run whatever python you would normally but add "-m python_mommy" after python~

```text
> cat hello.py

print("Hello, world"

> python -m python_mommy hello.py

File "/home/little_girl/hello.py", line 1
    print("Hello, world"
         ^
SyntaxError: '(' was never closed

mommy knows her little girl can do better~ ❤️

>_
```

You can alias mommy directly to python if you want, 

```text
> alias python="python -m python_mommy"
```

# Configuration

Mommy will read the following environment variables to make her messages better for you~ ❤️

* `PYTHON_MOMMYS_LITTLE` - what to call you~ (default: "girl")
* `PYTHON_MOMMYS_PRONOUNS` - what pronouns mommy will use for themself~ (default: "her")
* `PYTHON_MOMMYS_ROLES` - what role mommy will have~ (default "mommy")
* `PYTHON_MOMMYS_EMOTES` - what emotes mommy will have~ (default "❤️/💖/💗/💓/💞")

All of these options can take a `/` separated list. Mommy will randomly select one of them whenever she talks to you~

For example, the phrase "mommy loves her little girl~ 💞" is "PYTHON_MOMMYS_ROLE loves PYTHON_MOMMYS_PRONOUNS little PYTHON_MOMMYS_LITTLE~"

So if you set `PYTHON_MOMMYS_ROLES="daddy"`, `PYTHON_MOMMYS_PRONOUNS="his/their"`, and `PYTHON_MOMMYS_LITTLE="boy/pet/baby"` then you might get any of

* daddy loves their little boy~ ❤️
* daddy loves his little pet~ 💗
* daddy loves their little baby~ 💗

And so on~ 💓


# Configuration (kink)

<details>

<summary>
<b>THIS IS NSFW, STOP READING IF YOU WANT MOMMY TO REMAIN INNOCENT!</b>
</summary>

...

...

Good pet~ ❤️

All of mommy's NSFW content is hidden behind PYTHON_MOMMYS_MOODS, where "thirsty" is heavy teasing/flirting and "yikes" is full harsh dommy mommy kink~

You can enable "true mommy chaos mode" by setting `PYTHON_MOMMYS_MOODS="chill/thirsty/yikes"`, making mommy oscillate wildly between light positive affirmation and trying to break you in half~

* `PYTHON_MOMMYS_MOODS` - how kinky mommy will be~ (default: "chill", possible values "chill", "thirsty", "yikes")
* `PYTHON_MOMMYS_PARTS` - what part of mommy you should crave~ (default: "milk")
* `PYTHON_MOMMYS_FUCKING` - what to call mommy's pet~ (default: "slut/toy/pet/pervert/whore")

-----

**Here's some examples of mommy being thirsty~ ❤️**

*tugs your leash*
that's a VERY good girl~ 💞

*smooches your forehead*
good job~ 💗

are you just keysmashing now~?
cute~ 💖

if you don't learn how to code better, mommy is going to put you in time-out~ 💓

-----

**And here's some examples of mommy being yikes~ 💞**

good slut~
you've earned five minutes with the buzzy wand~ 💗

*slides her finger in your mouth*
that's a good little toy~ ❤️

get on your knees and beg mommy for forgiveness you pervert~ 💗

mommy is starting to wonder if you should just give up and become her breeding stock~ 💗

</details>

# Licensing
mommy likes freedom~ ❤️, and is licensed under [MIT](LICENSE-MIT).

==> pythonmommy-0.1.2.tar.gz: pythonmommy-0.1.2/README.md <==
# pythonmommy

[View on PyPI](https://pypi.org/project/pythonmommy/)

Mommy's here to support you when running python~ ❤️

THIS IS A PORT OF Gankra/cargo-mommy

# Installation

Install python-mommy like you would any other python package~

```text
> pip install pythonmommy
```

# Usage

Run whatever python you would normally but add "-m python_mommy" after python~

```text
> cat hello.py

print("Hello, world"

> python -m pythonmommy hello.py

File "/home/little_girl/hello.py", line 1
    print("Hello, world"
         ^
SyntaxError: '(' was never closed

mommy knows her little girl can do better~ ❤️

>_
```

You can alias mommy directly to python if you want, 

```text
> alias python="python -m pythonmommy"
```

# Configuration

Mommy will read the following environment variables to make her messages better for you~ ❤️

* `PYTHON_MOMMYS_LITTLE` - what to call you~ (default: "girl")
* `PYTHON_MOMMYS_PRONOUNS` - what pronouns mommy will use for themself~ (default: "her")
* `PYTHON_MOMMYS_ROLES` - what role mommy will have~ (default "mommy")
* `PYTHON_MOMMYS_EMOTES` - what emotes mommy will have~ (default "❤️/💖/💗/💓/💞")

All of these options can take a `/` separated list. Mommy will randomly select one of them whenever she talks to you~

For example, the phrase "mommy loves her little girl~ 💞" is "PYTHON_MOMMYS_ROLE loves PYTHON_MOMMYS_PRONOUNS little PYTHON_MOMMYS_LITTLE~"

So if you set `PYTHON_MOMMYS_ROLES="daddy"`, `PYTHON_MOMMYS_PRONOUNS="his/their"`, and `PYTHON_MOMMYS_LITTLE="boy/pet/baby"` then you might get any of

* daddy loves their little boy~ ❤️
* daddy loves his little pet~ 💗
* daddy loves their little baby~ 💗

And so on~ 💓


# Configuration (kink)

<details>

<summary>
<b>THIS IS NSFW, STOP READING IF YOU WANT MOMMY TO REMAIN INNOCENT!</b>
</summary>

...

...

Good pet~ ❤️

All of mommy's NSFW content is hidden behind PYTHON_MOMMYS_MOODS, where "thirsty" is heavy teasing/flirting and "yikes" is full harsh dommy mommy kink~

You can enable "true mommy chaos mode" by setting `PYTHON_MOMMYS_MOODS="chill/thirsty/yikes"`, making mommy oscillate wildly between light positive affirmation and trying to break you in half~

* `PYTHON_MOMMYS_MOODS` - how kinky mommy will be~ (default: "chill", possible values "chill", "thirsty", "yikes")
* `PYTHON_MOMMYS_PARTS` - what part of mommy you should crave~ (default: "milk")
* `PYTHON_MOMMYS_FUCKING` - what to call mommy's pet~ (default: "slut/toy/pet/pervert/whore")

-----

**Here's some examples of mommy being thirsty~ ❤️**

*tugs your leash*
that's a VERY good girl~ 💞

*smooches your forehead*
good job~ 💗

are you just keysmashing now~?
cute~ 💖

if you don't learn how to code better, mommy is going to put you in time-out~ 💓

-----

**And here's some examples of mommy being yikes~ 💞**

good slut~
you've earned five minutes with the buzzy wand~ 💗

*slides her finger in your mouth*
that's a good little toy~ ❤️

get on your knees and beg mommy for forgiveness you pervert~ 💗

mommy is starting to wonder if you should just give up and become her breeding stock~ 💗

</details>

# Licensing
mommy likes freedom~ ❤️, and is licensed under [MIT](LICENSE-MIT).
